@@ -97,12 +97,12 @@ class Release(setuptools.Command):
             git = sh.git
             short_version = "v{0}".format(self.version)
             long_version = "version {0}".format(self.version)
-            out = ""
+            print "---"
             try:
-                out = str(git.commit("-a", "-m", long_version))
-            except sh.ErrorReturnCode:
-                if not "nothing to commit" in out:
-                    sys.exit(out)
+                git.commit("-a", "-m", long_version)
+            except sh.ErrorReturnCode as error:
+                if not "nothing to commit" in error.stdout:
+                    sys.exit(error.stdout)
             print "*" # STUCK IN THE PUSH ... transfrom into some iter version ?
             # to see if there is a message ? Maybe that's a root id pb. Seems so.
             print git.push()
